package com.yanzhu.jh.project.mapper;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectBuildDesignData;

/**
 * 设计管理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-03-16
 */
public interface SurProjectBuildDesignDataMapper 
{
    /**
     * 查询设计管理
     * 
     * @param id 设计管理主键
     * @return 设计管理
     */
    public SurProjectBuildDesignData selectSurProjectBuildDesignDataById(Long id);

    /**
     * 查询设计管理列表
     * 
     * @param surProjectBuildDesignData 设计管理
     * @return 设计管理集合
     */
    public List<SurProjectBuildDesignData> selectSurProjectBuildDesignDataList(SurProjectBuildDesignData surProjectBuildDesignData);

    /**
     * 新增设计管理
     * 
     * @param surProjectBuildDesignData 设计管理
     * @return 结果
     */
    public int insertSurProjectBuildDesignData(SurProjectBuildDesignData surProjectBuildDesignData);

    /**
     * 修改设计管理
     * 
     * @param surProjectBuildDesignData 设计管理
     * @return 结果
     */
    public int updateSurProjectBuildDesignData(SurProjectBuildDesignData surProjectBuildDesignData);

    /**
     * 删除设计管理
     * 
     * @param id 设计管理主键
     * @return 结果
     */
    public int deleteSurProjectBuildDesignDataById(Long id);

    /**
     * 批量删除设计管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurProjectBuildDesignDataByIds(Long[] ids);
    /**
     * 按周查询设计计划
     * @param projectId,startDate,endDate
     * @return
     */
    public  List<SurProjectBuildDesignData> selectWeekData(SurProjectBuildDesignData where);
}
